# -*- coding: utf-8 -*-
"""Package __init__"""

from osdu._version import VERSION_INFO
from osdu._version import VERSION_MINOR
from osdu._version import VERSION_MAJOR
from osdu._version import VERSION_PATCH
from osdu._version import __version__


__all__ = [
    "VERSION_MAJOR",
    "VERSION_MINOR",
    "VERSION_PATCH",
    "VERSION_INFO",
    "__version__",
]
